<?php

return [
    'Names' => [
        'af' => 'អាហ្វ្រិកាន',
        'af_NA' => 'អាហ្វ្រិកាន (ណាមីប៊ី)',
        'af_ZA' => 'អាហ្វ្រិកាន (អាហ្វ្រិកខាងត្បូង)',
        'ak' => 'អាកាន',
        'ak_GH' => 'អាកាន (ហ្គាណា)',
        'am' => 'អាំហារិក',
        'am_ET' => 'អាំហារិក (អេត្យូពី)',
        'ar' => 'អារ៉ាប់',
        'ar_001' => 'អារ៉ាប់ (ពិភពលោក)',
        'ar_AE' => 'អារ៉ាប់ (អេមីរ៉ាត​អារ៉ាប់​រួម)',
        'ar_BH' => 'អារ៉ាប់ (បារ៉ែន)',
        'ar_DJ' => 'អារ៉ាប់ (ជីប៊ូទី)',
        'ar_DZ' => 'អារ៉ាប់ (អាល់ហ្សេរី)',
        'ar_EG' => 'អារ៉ាប់ (អេហ្ស៊ីប)',
        'ar_EH' => 'អារ៉ាប់ (សាហារ៉ាខាងលិច)',
        'ar_ER' => 'អារ៉ាប់ (អេរីត្រេ)',
        'ar_IL' => 'អារ៉ាប់ (អ៊ីស្រាអែល)',
        'ar_IQ' => 'អារ៉ាប់ (អ៊ីរ៉ាក់)',
        'ar_JO' => 'អារ៉ាប់ (ហ៊្សកដានី)',
        'ar_KM' => 'អារ៉ាប់ (កូម័រ)',
        'ar_KW' => 'អារ៉ាប់ (កូវ៉ែត)',
        'ar_LB' => 'អារ៉ាប់ (លីបង់)',
        'ar_LY' => 'អារ៉ាប់ (លីប៊ី)',
        'ar_MA' => 'អារ៉ាប់ (ម៉ារ៉ុក)',
        'ar_MR' => 'អារ៉ាប់ (ម៉ូរីតានី)',
        'ar_OM' => 'អារ៉ាប់ (អូម៉ង់)',
        'ar_PS' => 'អារ៉ាប់ (ដែនដីប៉ាឡេស្ទីន)',
        'ar_QA' => 'អារ៉ាប់ (កាតា)',
        'ar_SA' => 'អារ៉ាប់ (អារ៉ាប៊ីសាអូឌីត)',
        'ar_SD' => 'អារ៉ាប់ (ស៊ូដង់)',
        'ar_SO' => 'អារ៉ាប់ (សូម៉ាលី)',
        'ar_SS' => 'អារ៉ាប់ (ស៊ូដង់​ខាង​ត្បូង)',
        'ar_SY' => 'អារ៉ាប់ (ស៊ីរី)',
        'ar_TD' => 'អារ៉ាប់ (ឆាដ)',
        'ar_TN' => 'អារ៉ាប់ (ទុយនីស៊ី)',
        'ar_YE' => 'អារ៉ាប់ (យេម៉ែន)',
        'as' => 'អាសាមីស',
        'as_IN' => 'អាសាមីស (ឥណ្ឌា)',
        'az' => 'អាស៊ែបៃហ្សង់',
        'az_AZ' => 'អាស៊ែបៃហ្សង់ (អាស៊ែបៃហ្សង់)',
        'az_Cyrl' => 'អាស៊ែបៃហ្សង់ (ស៊ីរីលីក)',
        'az_Cyrl_AZ' => 'អាស៊ែបៃហ្សង់ (ស៊ីរីលីក, អាស៊ែបៃហ្សង់)',
        'az_Latn' => 'អាស៊ែបៃហ្សង់ (ឡាតាំង)',
        'az_Latn_AZ' => 'អាស៊ែបៃហ្សង់ (ឡាតាំង, អាស៊ែបៃហ្សង់)',
        'be' => 'បេឡារុស',
        'be_BY' => 'បេឡារុស (បេឡារុស)',
        'bg' => 'ប៊ុលហ្ការី',
        'bg_BG' => 'ប៊ុលហ្ការី (ប៊ុលហ្ការី)',
        'bm' => 'បាម្បារា',
        'bm_ML' => 'បាម្បារា (ម៉ាលី)',
        'bn' => 'បង់ក្លាដែស',
        'bn_BD' => 'បង់ក្លាដែស (បង់ក្លាដែស)',
        'bn_IN' => 'បង់ក្លាដែស (ឥណ្ឌា)',
        'bo' => 'ទីបេ',
        'bo_CN' => 'ទីបេ (ចិន)',
        'bo_IN' => 'ទីបេ (ឥណ្ឌា)',
        'br' => 'ប្រ៊ីស្តុន',
        'br_FR' => 'ប្រ៊ីស្តុន (បារាំង)',
        'bs' => 'បូស្នី',
        'bs_BA' => 'បូស្នី (បូស្ន៊ី និងហឺហ្ស៊ីហ្គូវីណា)',
        'bs_Cyrl' => 'បូស្នី (ស៊ីរីលីក)',
        'bs_Cyrl_BA' => 'បូស្នី (ស៊ីរីលីក, បូស្ន៊ី និងហឺហ្ស៊ីហ្គូវីណា)',
        'bs_Latn' => 'បូស្នី (ឡាតាំង)',
        'bs_Latn_BA' => 'បូស្នី (ឡាតាំង, បូស្ន៊ី និងហឺហ្ស៊ីហ្គូវីណា)',
        'ca' => 'កាតាឡាន',
        'ca_AD' => 'កាតាឡាន (អង់ដូរ៉ា)',
        'ca_ES' => 'កាតាឡាន (អេស្ប៉ាញ)',
        'ca_FR' => 'កាតាឡាន (បារាំង)',
        'ca_IT' => 'កាតាឡាន (អ៊ីតាលី)',
        'ce' => 'ឈីឆេន',
        'ce_RU' => 'ឈីឆេន (រុស្ស៊ី)',
        'cs' => 'ឆែក',
        'cs_CZ' => 'ឆែក (ឆែក)',
        'cv' => 'ឈូវ៉ាស',
        'cv_RU' => 'ឈូវ៉ាស (រុស្ស៊ី)',
        'cy' => 'វេល',
        'cy_GB' => 'វេល (ចក្រភព​អង់គ្លេស)',
        'da' => 'ដាណឺម៉ាក',
        'da_DK' => 'ដាណឺម៉ាក (ដាណឺម៉ាក)',
        'da_GL' => 'ដាណឺម៉ាក (ហ្គ្រោអង់ឡង់)',
        'de' => 'អាល្លឺម៉ង់',
        'de_AT' => 'អាល្លឺម៉ង់ (អូទ្រីស)',
        'de_BE' => 'អាល្លឺម៉ង់ (បែលហ្ស៊ិក)',
        'de_CH' => 'អាល្លឺម៉ង់ (ស្វ៊ីស)',
        'de_DE' => 'អាល្លឺម៉ង់ (អាល្លឺម៉ង់)',
        'de_IT' => 'អាល្លឺម៉ង់ (អ៊ីតាលី)',
        'de_LI' => 'អាល្លឺម៉ង់ (លិចតិនស្ដាញ)',
        'de_LU' => 'អាល្លឺម៉ង់ (លុចសំបួ)',
        'dz' => 'ដុងខា',
        'dz_BT' => 'ដុងខា (ប៊ូតង់)',
        'ee' => 'អ៊ីវ',
        'ee_GH' => 'អ៊ីវ (ហ្គាណា)',
        'ee_TG' => 'អ៊ីវ (តូហ្គោ)',
        'el' => 'ក្រិក',
        'el_CY' => 'ក្រិក (ស៊ីប)',
        'el_GR' => 'ក្រិក (ក្រិក)',
        'en' => 'អង់គ្លេស',
        'en_001' => 'អង់គ្លេស (ពិភពលោក)',
        'en_150' => 'អង់គ្លេស (អឺរ៉ុប)',
        'en_AE' => 'អង់គ្លេស (អេមីរ៉ាត​អារ៉ាប់​រួម)',
        'en_AG' => 'អង់គ្លេស (អង់ទីហ្គា និង បាប៊ុយដា)',
        'en_AI' => 'អង់គ្លេស (អង់ហ្គីឡា)',
        'en_AS' => 'អង់គ្លេស (សាម័រ អាមេរិកាំង)',
        'en_AT' => 'អង់គ្លេស (អូទ្រីស)',
        'en_AU' => 'អង់គ្លេស (អូស្ត្រាលី)',
        'en_BB' => 'អង់គ្លេស (បាបាដុស)',
        'en_BE' => 'អង់គ្លេស (បែលហ្ស៊ិក)',
        'en_BI' => 'អង់គ្លេស (ប៊ូរុនឌី)',
        'en_BM' => 'អង់គ្លេស (ប៊ឺមុយដា)',
        'en_BS' => 'អង់គ្លេស (បាហាម៉ា)',
        'en_BW' => 'អង់គ្លេស (បុតស្វាណា)',
        'en_BZ' => 'អង់គ្លេស (បេលី)',
        'en_CA' => 'អង់គ្លេស (កាណាដា)',
        'en_CC' => 'អង់គ្លេស (កោះ​កូកូស [គីលីង])',
        'en_CH' => 'អង់គ្លេស (ស្វ៊ីស)',
        'en_CK' => 'អង់គ្លេស (កោះ​ខូក)',
        'en_CM' => 'អង់គ្លេស (កាមេរូន)',
        'en_CX' => 'អង់គ្លេស (កោះ​គ្រីស្មាស)',
        'en_CY' => 'អង់គ្លេស (ស៊ីប)',
        'en_DE' => 'អង់គ្លេស (អាល្លឺម៉ង់)',
        'en_DK' => 'អង់គ្លេស (ដាណឺម៉ាក)',
        'en_DM' => 'អង់គ្លេស (ដូមីនីក)',
        'en_ER' => 'អង់គ្លេស (អេរីត្រេ)',
        'en_FI' => 'អង់គ្លេស (ហ្វាំងឡង់)',
        'en_FJ' => 'អង់គ្លេស (ហ្វីជី)',
        'en_FK' => 'អង់គ្លេស (កោះ​ហ្វក់ឡែន)',
        'en_FM' => 'អង់គ្លេស (មីក្រូណេស៊ី)',
        'en_GB' => 'អង់គ្លេស (ចក្រភព​អង់គ្លេស)',
        'en_GD' => 'អង់គ្លេស (ហ្គ្រើណាដ)',
        'en_GG' => 'អង់គ្លេស (ហ្គេនស៊ី)',
        'en_GH' => 'អង់គ្លេស (ហ្គាណា)',
        'en_GI' => 'អង់គ្លេស (ហ្ស៊ីប្រាល់តា)',
        'en_GM' => 'អង់គ្លេស (ហ្គំប៊ី)',
        'en_GU' => 'អង់គ្លេស (ហ្គាំ)',
        'en_GY' => 'អង់គ្លេស (ហ្គីយ៉ាន)',
        'en_HK' => 'អង់គ្លេស (ហុងកុង តំបន់រដ្ឋបាលពិសេសចិន)',
        'en_IE' => 'អង់គ្លេស (អៀរឡង់)',
        'en_IL' => 'អង់គ្លេស (អ៊ីស្រាអែល)',
        'en_IM' => 'អង់គ្លេស (អែលអុហ្វមែន)',
        'en_IN' => 'អង់គ្លេស (ឥណ្ឌា)',
        'en_IO' => 'អង់គ្លេស (ដែនដី​អង់គ្លេស​នៅ​មហា​សមុទ្រ​ឥណ្ឌា)',
        'en_JE' => 'អង់គ្លេស (ជើស៊ី)',
        'en_JM' => 'អង់គ្លេស (ហ្សាម៉ាអ៊ីក)',
        'en_KE' => 'អង់គ្លេស (កេនយ៉ា)',
        'en_KI' => 'អង់គ្លេស (គិរីបាទី)',
        'en_KN' => 'អង់គ្លេស (សាំង​គីត និង ណេវីស)',
        'en_KY' => 'អង់គ្លេស (កោះ​កៃម៉ង់)',
        'en_LC' => 'អង់គ្លេស (សាំងលូស៊ី)',
        'en_LR' => 'អង់គ្លេស (លីបេរីយ៉ា)',
        'en_LS' => 'អង់គ្លេស (ឡេសូតូ)',
        'en_MG' => 'អង់គ្លេស (ម៉ាដាហ្គាស្កា)',
        'en_MH' => 'អង់គ្លេស (កោះ​ម៉ាស់សល)',
        'en_MO' => 'អង់គ្លេស (ម៉ាកាវ តំបន់រដ្ឋបាលពិសេសចិន)',
        'en_MP' => 'អង់គ្លេស (កោះ​ម៉ារីណា​ខាង​ជើង)',
        'en_MS' => 'អង់គ្លេស (ម៉ុងស៊ែរ៉ា)',
        'en_MT' => 'អង់គ្លេស (ម៉ាល់ត៍)',
        'en_MU' => 'អង់គ្លេស (ម៉ូរីស)',
        'en_MV' => 'អង់គ្លេស (ម៉ាល់ឌីវ)',
        'en_MW' => 'អង់គ្លេស (ម៉ាឡាវី)',
        'en_MY' => 'អង់គ្លេស (ម៉ាឡេស៊ី)',
        'en_NA' => 'អង់គ្លេស (ណាមីប៊ី)',
        'en_NF' => 'អង់គ្លេស (កោះ​ណ័រហ្វក់)',
        'en_NG' => 'អង់គ្លេស (នីហ្សេរីយ៉ា)',
        'en_NL' => 'អង់គ្លេស (ហូឡង់)',
        'en_NR' => 'អង់គ្លេស (ណូរូ)',
        'en_NU' => 'អង់គ្លេស (ណៀ)',
        'en_NZ' => 'អង់គ្លេស (នូវែល​សេឡង់)',
        'en_PG' => 'អង់គ្លេស (ប៉ាពូអាស៊ី​នូវែលហ្គីណេ)',
        'en_PH' => 'អង់គ្លេស (ហ្វ៊ីលីពីន)',
        'en_PK' => 'អង់គ្លេស (ប៉ាគីស្ថាន)',
        'en_PN' => 'អង់គ្លេស (កោះ​ភីតកាន)',
        'en_PR' => 'អង់គ្លេស (ព័រតូរីកូ)',
        'en_PW' => 'អង់គ្លេស (ផៅឡូ)',
        'en_RW' => 'អង់គ្លេស (រវ៉ាន់ដា)',
        'en_SB' => 'អង់គ្លេស (កោះ​សូឡូម៉ុង)',
        'en_SC' => 'អង់គ្លេស (សីស្ហែល)',
        'en_SD' => 'អង់គ្លេស (ស៊ូដង់)',
        'en_SE' => 'អង់គ្លេស (ស៊ុយអែត)',
        'en_SG' => 'អង់គ្លេស (សិង្ហបុរី)',
        'en_SH' => 'អង់គ្លេស (សង់​ហេឡេណា)',
        'en_SI' => 'អង់គ្លេស (ស្លូវេនី)',
        'en_SL' => 'អង់គ្លេស (សៀរ៉ាឡេអូន)',
        'en_SS' => 'អង់គ្លេស (ស៊ូដង់​ខាង​ត្បូង)',
        'en_SX' => 'អង់គ្លេស (សីង​ម៉ាធីន)',
        'en_SZ' => 'អង់គ្លេស (ស្វាស៊ីឡង់)',
        'en_TC' => 'អង់គ្លេស (កោះ​ទួគ និង កៃកូស)',
        'en_TK' => 'អង់គ្លេស (តូខេឡៅ)',
        'en_TO' => 'អង់គ្លេស (តុងហ្គា)',
        'en_TT' => 'អង់គ្លេស (ទ្រីនីដាត និង​តូបាហ្គោ)',
        'en_TV' => 'អង់គ្លេស (ទូវ៉ាលូ)',
        'en_TZ' => 'អង់គ្លេស (តង់សានី)',
        'en_UG' => 'អង់គ្លេស (អ៊ូហ្គង់ដា)',
        'en_UM' => 'អង់គ្លេស (កោះ​អៅឡាយីង​អាមេរិក)',
        'en_US' => 'អង់គ្លេស (សហរដ្ឋអាមេរិក)',
        'en_VC' => 'អង់គ្លេស (សាំង​វ៉ាំងសង់ និង ហ្គ្រេណាឌីន)',
        'en_VG' => 'អង់គ្លេស (កោះ​វឺជិន​ចក្រភព​អង់គ្លេស)',
        'en_VI' => 'អង់គ្លេស (កោះ​វឺជីន​អាមេរិក)',
        'en_VU' => 'អង់គ្លេស (វ៉ានូទូ)',
        'en_WS' => 'អង់គ្លេស (សាម័រ)',
        'en_ZA' => 'អង់គ្លេស (អាហ្វ្រិកខាងត្បូង)',
        'en_ZM' => 'អង់គ្លេស (សំប៊ី)',
        'en_ZW' => 'អង់គ្លេស (ស៊ីមបាវ៉េ)',
        'eo' => 'អេស្ពេរ៉ាន់តូ',
        'eo_001' => 'អេស្ពេរ៉ាន់តូ (ពិភពលោក)',
        'es' => 'អេស្ប៉ាញ',
        'es_419' => 'អេស្ប៉ាញ (អាមេរិក​ឡាទីន)',
        'es_AR' => 'អេស្ប៉ាញ (អាហ្សង់ទីន)',
        'es_BO' => 'អេស្ប៉ាញ (បូលីវី)',
        'es_BR' => 'អេស្ប៉ាញ (ប្រេស៊ីល)',
        'es_BZ' => 'អេស្ប៉ាញ (បេលី)',
        'es_CL' => 'អេស្ប៉ាញ (ស៊ីលី)',
        'es_CO' => 'អេស្ប៉ាញ (កូឡុំប៊ី)',
        'es_CR' => 'អេស្ប៉ាញ (កូស្តារីកា)',
        'es_CU' => 'អេស្ប៉ាញ (គុយបា)',
        'es_DO' => 'អេស្ប៉ាញ (សាធារណរដ្ឋ​ដូមីនីក)',
        'es_EC' => 'អេស្ប៉ាញ (អេក្វាទ័រ)',
        'es_ES' => 'អេស្ប៉ាញ (អេស្ប៉ាញ)',
        'es_GQ' => 'អេស្ប៉ាញ (ហ្គីណេអេក្វាទ័រ)',
        'es_GT' => 'អេស្ប៉ាញ (ក្វាតេម៉ាឡា)',
        'es_HN' => 'អេស្ប៉ាញ (ហុងឌូរ៉ាស)',
        'es_MX' => 'អេស្ប៉ាញ (ម៉ិកស៊ិក)',
        'es_NI' => 'អេស្ប៉ាញ (នីការ៉ាហ្គា)',
        'es_PA' => 'អេស្ប៉ាញ (ប៉ាណាម៉ា)',
        'es_PE' => 'អេស្ប៉ាញ (ប៉េរូ)',
        'es_PH' => 'អេស្ប៉ាញ (ហ្វ៊ីលីពីន)',
        'es_PR' => 'អេស្ប៉ាញ (ព័រតូរីកូ)',
        'es_PY' => 'អេស្ប៉ាញ (ប៉ារ៉ាហ្គាយ)',
        'es_SV' => 'អេស្ប៉ាញ (អែលសាល់វ៉ាឌ័រ)',
        'es_US' => 'អេស្ប៉ាញ (សហរដ្ឋអាមេរិក)',
        'es_UY' => 'អេស្ប៉ាញ (អ៊ុយរូហ្គាយ)',
        'es_VE' => 'អេស្ប៉ាញ (វ៉េណេស៊ុយអេឡា)',
        'et' => 'អេស្តូនី',
        'et_EE' => 'អេស្តូនី (អេស្តូនី)',
        'eu' => 'បាសខ៍',
        'eu_ES' => 'បាសខ៍ (អេស្ប៉ាញ)',
        'fa' => 'ភឺសៀន',
        'fa_AF' => 'ភឺសៀន (អាហ្វហ្កានីស្ថាន)',
        'fa_IR' => 'ភឺសៀន (អ៊ីរ៉ង់)',
        'ff' => 'ហ្វ៊ូឡា',
        'ff_Adlm' => 'ហ្វ៊ូឡា (អាតឡាម)',
        'ff_Adlm_BF' => 'ហ្វ៊ូឡា (អាតឡាម, បួគីណាហ្វាសូ)',
        'ff_Adlm_CM' => 'ហ្វ៊ូឡា (អាតឡាម, កាមេរូន)',
        'ff_Adlm_GH' => 'ហ្វ៊ូឡា (អាតឡាម, ហ្គាណា)',
        'ff_Adlm_GM' => 'ហ្វ៊ូឡា (អាតឡាម, ហ្គំប៊ី)',
        'ff_Adlm_GN' => 'ហ្វ៊ូឡា (អាតឡាម, ហ្គីណេ)',
        'ff_Adlm_GW' => 'ហ្វ៊ូឡា (អាតឡាម, ហ្គីណេប៊ីស្សូ)',
        'ff_Adlm_LR' => 'ហ្វ៊ូឡា (អាតឡាម, លីបេរីយ៉ា)',
        'ff_Adlm_MR' => 'ហ្វ៊ូឡា (អាតឡាម, ម៉ូរីតានី)',
        'ff_Adlm_NE' => 'ហ្វ៊ូឡា (អាតឡាម, នីហ្សេ)',
        'ff_Adlm_NG' => 'ហ្វ៊ូឡា (អាតឡាម, នីហ្សេរីយ៉ា)',
        'ff_Adlm_SL' => 'ហ្វ៊ូឡា (អាតឡាម, សៀរ៉ាឡេអូន)',
        'ff_Adlm_SN' => 'ហ្វ៊ូឡា (អាតឡាម, សេណេហ្គាល់)',
        'ff_CM' => 'ហ្វ៊ូឡា (កាមេរូន)',
        'ff_GN' => 'ហ្វ៊ូឡា (ហ្គីណេ)',
        'ff_Latn' => 'ហ្វ៊ូឡា (ឡាតាំង)',
        'ff_Latn_BF' => 'ហ្វ៊ូឡា (ឡាតាំង, បួគីណាហ្វាសូ)',
        'ff_Latn_CM' => 'ហ្វ៊ូឡា (ឡាតាំង, កាមេរូន)',
        'ff_Latn_GH' => 'ហ្វ៊ូឡា (ឡាតាំង, ហ្គាណា)',
        'ff_Latn_GM' => 'ហ្វ៊ូឡា (ឡាតាំង, ហ្គំប៊ី)',
        'ff_Latn_GN' => 'ហ្វ៊ូឡា (ឡាតាំង, ហ្គីណេ)',
        'ff_Latn_GW' => 'ហ្វ៊ូឡា (ឡាតាំង, ហ្គីណេប៊ីស្សូ)',
        'ff_Latn_LR' => 'ហ្វ៊ូឡា (ឡាតាំង, លីបេរីយ៉ា)',
        'ff_Latn_MR' => 'ហ្វ៊ូឡា (ឡាតាំង, ម៉ូរីតានី)',
        'ff_Latn_NE' => 'ហ្វ៊ូឡា (ឡាតាំង, នីហ្សេ)',
        'ff_Latn_NG' => 'ហ្វ៊ូឡា (ឡាតាំង, នីហ្សេរីយ៉ា)',
        'ff_Latn_SL' => 'ហ្វ៊ូឡា (ឡាតាំង, សៀរ៉ាឡេអូន)',
        'ff_Latn_SN' => 'ហ្វ៊ូឡា (ឡាតាំង, សេណេហ្គាល់)',
        'ff_MR' => 'ហ្វ៊ូឡា (ម៉ូរីតានី)',
        'ff_SN' => 'ហ្វ៊ូឡា (សេណេហ្គាល់)',
        'fi' => 'ហ្វាំងឡង់',
        'fi_FI' => 'ហ្វាំងឡង់ (ហ្វាំងឡង់)',
        'fo' => 'ហ្វារូស',
        'fo_DK' => 'ហ្វារូស (ដាណឺម៉ាក)',
        'fo_FO' => 'ហ្វារូស (កោះ​ហ្វារ៉ូ)',
        'fr' => 'បារាំង',
        'fr_BE' => 'បារាំង (បែលហ្ស៊ិក)',
        'fr_BF' => 'បារាំង (បួគីណាហ្វាសូ)',
        'fr_BI' => 'បារាំង (ប៊ូរុនឌី)',
        'fr_BJ' => 'បារាំង (បេណាំង)',
        'fr_BL' => 'បារាំង (សាំង​បាថេឡេមី)',
        'fr_CA' => 'បារាំង (កាណាដា)',
        'fr_CD' => 'បារាំង (កុងហ្គោ- គីនស្ហាសា)',
        'fr_CF' => 'បារាំង (សាធារណរដ្ឋអាហ្វ្រិកកណ្ដាល)',
        'fr_CG' => 'បារាំង (កុងហ្គោ - ប្រាហ្សាវីល)',
        'fr_CH' => 'បារាំង (ស្វ៊ីស)',
        'fr_CI' => 'បារាំង (កូតឌីវ័រ)',
        'fr_CM' => 'បារាំង (កាមេរូន)',
        'fr_DJ' => 'បារាំង (ជីប៊ូទី)',
        'fr_DZ' => 'បារាំង (អាល់ហ្សេរី)',
        'fr_FR' => 'បារាំង (បារាំង)',
        'fr_GA' => 'បារាំង (ហ្គាបុង)',
        'fr_GF' => 'បារាំង (ហ្គីអាណា បារាំង)',
        'fr_GN' => 'បារាំង (ហ្គីណេ)',
        'fr_GP' => 'បារាំង (ហ្គោដឺឡុប)',
        'fr_GQ' => 'បារាំង (ហ្គីណេអេក្វាទ័រ)',
        'fr_HT' => 'បារាំង (ហៃទី)',
        'fr_KM' => 'បារាំង (កូម័រ)',
        'fr_LU' => 'បារាំង (លុចសំបួ)',
        'fr_MA' => 'បារាំង (ម៉ារ៉ុក)',
        'fr_MC' => 'បារាំង (ម៉ូណាកូ)',
        'fr_MF' => 'បារាំង (សាំង​ម៉ាទីន)',
        'fr_MG' => 'បារាំង (ម៉ាដាហ្គាស្កា)',
        'fr_ML' => 'បារាំង (ម៉ាលី)',
        'fr_MQ' => 'បារាំង (ម៉ាទីនីក)',
        'fr_MR' => 'បារាំង (ម៉ូរីតានី)',
        'fr_MU' => 'បារាំង (ម៉ូរីស)',
        'fr_NC' => 'បារាំង (នូវែល​កាឡេដូនី)',
        'fr_NE' => 'បារាំង (នីហ្សេ)',
        'fr_PF' => 'បារាំង (ប៉ូលី​ណេស៊ី​បារាំង)',
        'fr_PM' => 'បារាំង (សង់ព្យែរ និង​មីគីឡុង)',
        'fr_RE' => 'បារាំង (រេអុយញ៉ុង)',
        'fr_RW' => 'បារាំង (រវ៉ាន់ដា)',
        'fr_SC' => 'បារាំង (សីស្ហែល)',
        'fr_SN' => 'បារាំង (សេណេហ្គាល់)',
        'fr_SY' => 'បារាំង (ស៊ីរី)',
        'fr_TD' => 'បារាំង (ឆាដ)',
        'fr_TG' => 'បារាំង (តូហ្គោ)',
        'fr_TN' => 'បារាំង (ទុយនីស៊ី)',
        'fr_VU' => 'បារាំង (វ៉ានូទូ)',
        'fr_WF' => 'បារាំង (វ៉ាលីស និង​ហ្វូទូណា)',
        'fr_YT' => 'បារាំង (ម៉ាយុត)',
        'fy' => 'ហ្វ្រីស៊ានខាងលិច',
        'fy_NL' => 'ហ្វ្រីស៊ានខាងលិច (ហូឡង់)',
        'ga' => 'អៀរឡង់',
        'ga_GB' => 'អៀរឡង់ (ចក្រភព​អង់គ្លេស)',
        'ga_IE' => 'អៀរឡង់ (អៀរឡង់)',
        'gd' => 'ស្កុតហ្កែលិគ',
        'gd_GB' => 'ស្កុតហ្កែលិគ (ចក្រភព​អង់គ្លេស)',
        'gl' => 'ហ្កាលីស្យាន',
        'gl_ES' => 'ហ្កាលីស្យាន (អេស្ប៉ាញ)',
        'gu' => 'ហ្គុយ៉ារ៉ាទី',
        'gu_IN' => 'ហ្គុយ៉ារ៉ាទី (ឥណ្ឌា)',
        'gv' => 'មេន',
        'gv_IM' => 'មេន (អែលអុហ្វមែន)',
        'ha' => 'ហូសា',
        'ha_GH' => 'ហូសា (ហ្គាណា)',
        'ha_NE' => 'ហូសា (នីហ្សេ)',
        'ha_NG' => 'ហូសា (នីហ្សេរីយ៉ា)',
        'he' => 'ហេប្រឺ',
        'he_IL' => 'ហេប្រឺ (អ៊ីស្រាអែល)',
        'hi' => 'ហិណ្ឌី',
        'hi_IN' => 'ហិណ្ឌី (ឥណ្ឌា)',
        'hi_Latn' => 'ហិណ្ឌី (ឡាតាំង)',
        'hi_Latn_IN' => 'ហិណ្ឌី (ឡាតាំង, ឥណ្ឌា)',
        'hr' => 'ក្រូអាត',
        'hr_BA' => 'ក្រូអាត (បូស្ន៊ី និងហឺហ្ស៊ីហ្គូវីណា)',
        'hr_HR' => 'ក្រូអាត (ក្រូអាស៊ី)',
        'hu' => 'ហុងគ្រី',
        'hu_HU' => 'ហុងគ្រី (ហុងគ្រី)',
        'hy' => 'អាមេនី',
        'hy_AM' => 'អាមេនី (អាមេនី)',
        'ia' => 'អ៊ីនធើលីង',
        'ia_001' => 'អ៊ីនធើលីង (ពិភពលោក)',
        'id' => 'ឥណ្ឌូណេស៊ី',
        'id_ID' => 'ឥណ្ឌូណេស៊ី (ឥណ្ឌូណេស៊ី)',
        'ig' => 'អ៊ីកបូ',
        'ig_NG' => 'អ៊ីកបូ (នីហ្សេរីយ៉ា)',
        'ii' => 'ស៊ីឈាន់យី',
        'ii_CN' => 'ស៊ីឈាន់យី (ចិន)',
        'is' => 'អ៊ីស្លង់',
        'is_IS' => 'អ៊ីស្លង់ (អ៊ីស្លង់)',
        'it' => 'អ៊ីតាលី',
        'it_CH' => 'អ៊ីតាលី (ស្វ៊ីស)',
        'it_IT' => 'អ៊ីតាលី (អ៊ីតាលី)',
        'it_SM' => 'អ៊ីតាលី (សាន​ម៉ារីណូ)',
        'it_VA' => 'អ៊ីតាលី (បុរី​វ៉ាទីកង់)',
        'ja' => 'ជប៉ុន',
        'ja_JP' => 'ជប៉ុន (ជប៉ុន)',
        'jv' => 'ជ្វា',
        'jv_ID' => 'ជ្វា (ឥណ្ឌូណេស៊ី)',
        'ka' => 'ហ្សក​ហ្ស៊ី',
        'ka_GE' => 'ហ្សក​ហ្ស៊ី (ហ្សកហ្ស៊ី)',
        'ki' => 'គីគូយូ',
        'ki_KE' => 'គីគូយូ (កេនយ៉ា)',
        'kk' => 'កាហ្សាក់',
        'kk_KZ' => 'កាហ្សាក់ (កាហ្សាក់ស្ថាន)',
        'kl' => 'កាឡាលលីស៊ុត',
        'kl_GL' => 'កាឡាលលីស៊ុត (ហ្គ្រោអង់ឡង់)',
        'km' => 'ខ្មែរ',
        'km_KH' => 'ខ្មែរ (កម្ពុជា)',
        'kn' => 'ខាណាដា',
        'kn_IN' => 'ខាណាដា (ឥណ្ឌា)',
        'ko' => 'កូរ៉េ',
        'ko_KP' => 'កូរ៉េ (កូរ៉េ​ខាង​ជើង)',
        'ko_KR' => 'កូរ៉េ (កូរ៉េ​ខាង​ត្បូង)',
        'ks' => 'កាស្មៀរ',
        'ks_Arab' => 'កាស្មៀរ (អារ៉ាប់)',
        'ks_Arab_IN' => 'កាស្មៀរ (អារ៉ាប់, ឥណ្ឌា)',
        'ks_Deva' => 'កាស្មៀរ (ដាវ៉ាន់ណាការិ)',
        'ks_Deva_IN' => 'កាស្មៀរ (ដាវ៉ាន់ណាការិ, ឥណ្ឌា)',
        'ks_IN' => 'កាស្មៀរ (ឥណ្ឌា)',
        'ku' => 'ឃឺដ',
        'ku_TR' => 'ឃឺដ (តួកគី)',
        'kw' => 'កូនីស',
        'kw_GB' => 'កូនីស (ចក្រភព​អង់គ្លេស)',
        'ky' => '​កៀហ្ស៊ីស',
        'ky_KG' => '​កៀហ្ស៊ីស (កៀហ្ស៊ីស៊ីស្ថាន)',
        'lb' => 'លុចសំបួ',
        'lb_LU' => 'លុចសំបួ (លុចសំបួ)',
        'lg' => 'ហ្កាន់ដា',
        'lg_UG' => 'ហ្កាន់ដា (អ៊ូហ្គង់ដា)',
        'ln' => 'លីនកាឡា',
        'ln_AO' => 'លីនកាឡា (អង់ហ្គោឡា)',
        'ln_CD' => 'លីនកាឡា (កុងហ្គោ- គីនស្ហាសា)',
        'ln_CF' => 'លីនកាឡា (សាធារណរដ្ឋអាហ្វ្រិកកណ្ដាល)',
        'ln_CG' => 'លីនកាឡា (កុងហ្គោ - ប្រាហ្សាវីល)',
        'lo' => 'ឡាវ',
        'lo_LA' => 'ឡាវ (ឡាវ)',
        'lt' => 'លីទុយអានី',
        'lt_LT' => 'លីទុយអានី (លីទុយអានី)',
        'lu' => 'លូបាកាតានហ្គា',
        'lu_CD' => 'លូបាកាតានហ្គា (កុងហ្គោ- គីនស្ហាសា)',
        'lv' => 'ឡាតវី',
        'lv_LV' => 'ឡាតវី (ឡេតូនី)',
        'mg' => 'ម៉ាឡាហ្គាស៊ី',
        'mg_MG' => 'ម៉ាឡាហ្គាស៊ី (ម៉ាដាហ្គាស្កា)',
        'mi' => 'ម៉ោរី',
        'mi_NZ' => 'ម៉ោរី (នូវែល​សេឡង់)',
        'mk' => 'ម៉ាសេដូនី',
        'mk_MK' => 'ម៉ាសេដូនី (ម៉ាសេដ្វានខាងជើង)',
        'ml' => 'ម៉ាឡាយ៉ាឡាម',
        'ml_IN' => 'ម៉ាឡាយ៉ាឡាម (ឥណ្ឌា)',
        'mn' => 'ម៉ុងហ្គោលី',
        'mn_MN' => 'ម៉ុងហ្គោលី (ម៉ុងហ្គោលី)',
        'mr' => 'ម៉ារ៉ាធី',
        'mr_IN' => 'ម៉ារ៉ាធី (ឥណ្ឌា)',
        'ms' => 'ម៉ាឡេ',
        'ms_BN' => 'ម៉ាឡេ (ព្រុយណេ)',
        'ms_ID' => 'ម៉ាឡេ (ឥណ្ឌូណេស៊ី)',
        'ms_MY' => 'ម៉ាឡេ (ម៉ាឡេស៊ី)',
        'ms_SG' => 'ម៉ាឡេ (សិង្ហបុរី)',
        'mt' => 'ម៉ាល់តា',
        'mt_MT' => 'ម៉ាល់តា (ម៉ាល់ត៍)',
        'my' => 'ភូមា',
        'my_MM' => 'ភូមា (មីយ៉ាន់ម៉ា [ភូមា])',
        'nb' => 'ន័រវែស បុកម៉ាល់',
        'nb_NO' => 'ន័រវែស បុកម៉ាល់ (ន័រវែស)',
        'nb_SJ' => 'ន័រវែស បុកម៉ាល់ (ស្វាលបាដ និង ហ្សង់ម៉ាយេន)',
        'nd' => 'នេបេលេខាងជើង',
        'nd_ZW' => 'នេបេលេខាងជើង (ស៊ីមបាវ៉េ)',
        'ne' => 'នេប៉ាល់',
        'ne_IN' => 'នេប៉ាល់ (ឥណ្ឌា)',
        'ne_NP' => 'នេប៉ាល់ (នេប៉ាល់)',
        'nl' => 'ហូឡង់',
        'nl_AW' => 'ហូឡង់ (អារូបា)',
        'nl_BE' => 'ហូឡង់ (បែលហ្ស៊ិក)',
        'nl_BQ' => 'ហូឡង់ (ហូឡង់ ការ៉ាប៊ីន)',
        'nl_CW' => 'ហូឡង់ (កូរ៉ាកៅ)',
        'nl_NL' => 'ហូឡង់ (ហូឡង់)',
        'nl_SR' => 'ហូឡង់ (សូរីណាម)',
        'nl_SX' => 'ហូឡង់ (សីង​ម៉ាធីន)',
        'nn' => 'ន័រវែស នីនូស',
        'nn_NO' => 'ន័រវែស នីនូស (ន័រវែស)',
        'no' => 'ន័រវែស',
        'no_NO' => 'ន័រវែស (ន័រវែស)',
        'om' => 'អូរ៉ូម៉ូ',
        'om_ET' => 'អូរ៉ូម៉ូ (អេត្យូពី)',
        'om_KE' => 'អូរ៉ូម៉ូ (កេនយ៉ា)',
        'or' => 'អូឌៀ',
        'or_IN' => 'អូឌៀ (ឥណ្ឌា)',
        'os' => 'អូស៊ីទិក',
        'os_GE' => 'អូស៊ីទិក (ហ្សកហ្ស៊ី)',
        'os_RU' => 'អូស៊ីទិក (រុស្ស៊ី)',
        'pa' => 'បឹនជាពិ',
        'pa_Arab' => 'បឹនជាពិ (អារ៉ាប់)',
        'pa_Arab_PK' => 'បឹនជាពិ (អារ៉ាប់, ប៉ាគីស្ថាន)',
        'pa_Guru' => 'បឹនជាពិ (កុមុយឃី)',
        'pa_Guru_IN' => 'បឹនជាពិ (កុមុយឃី, ឥណ្ឌា)',
        'pa_IN' => 'បឹនជាពិ (ឥណ្ឌា)',
        'pa_PK' => 'បឹនជាពិ (ប៉ាគីស្ថាន)',
        'pl' => 'ប៉ូឡូញ',
        'pl_PL' => 'ប៉ូឡូញ (ប៉ូឡូញ)',
        'ps' => 'បាស្តូ',
        'ps_AF' => 'បាស្តូ (អាហ្វហ្កានីស្ថាន)',
        'ps_PK' => 'បាស្តូ (ប៉ាគីស្ថាន)',
        'pt' => 'ព័រទុយហ្គាល់',
        'pt_AO' => 'ព័រទុយហ្គាល់ (អង់ហ្គោឡា)',
        'pt_BR' => 'ព័រទុយហ្គាល់ (ប្រេស៊ីល)',
        'pt_CH' => 'ព័រទុយហ្គាល់ (ស្វ៊ីស)',
        'pt_CV' => 'ព័រទុយហ្គាល់ (កាប់វែរ)',
        'pt_GQ' => 'ព័រទុយហ្គាល់ (ហ្គីណេអេក្វាទ័រ)',
        'pt_GW' => 'ព័រទុយហ្គាល់ (ហ្គីណេប៊ីស្សូ)',
        'pt_LU' => 'ព័រទុយហ្គាល់ (លុចសំបួ)',
        'pt_MO' => 'ព័រទុយហ្គាល់ (ម៉ាកាវ តំបន់រដ្ឋបាលពិសេសចិន)',
        'pt_MZ' => 'ព័រទុយហ្គាល់ (ម៉ូសំប៊ិក)',
        'pt_PT' => 'ព័រទុយហ្គាល់ (ព័រទុយហ្កាល់)',
        'pt_ST' => 'ព័រទុយហ្គាល់ (សៅតូម៉េ និង ប្រាំងស៊ីប)',
        'pt_TL' => 'ព័រទុយហ្គាល់ (ទីម័រលេស្តេ)',
        'qu' => 'ហ្គិកឈួ',
        'qu_BO' => 'ហ្គិកឈួ (បូលីវី)',
        'qu_EC' => 'ហ្គិកឈួ (អេក្វាទ័រ)',
        'qu_PE' => 'ហ្គិកឈួ (ប៉េរូ)',
        'rm' => 'រ៉ូម៉ង់',
        'rm_CH' => 'រ៉ូម៉ង់ (ស្វ៊ីស)',
        'rn' => 'រុណ្ឌី',
        'rn_BI' => 'រុណ្ឌី (ប៊ូរុនឌី)',
        'ro' => 'រូម៉ានី',
        'ro_MD' => 'រូម៉ានី (ម៉ុលដាវី)',
        'ro_RO' => 'រូម៉ានី (រូម៉ានី)',
        'ru' => 'រុស្ស៊ី',
        'ru_BY' => 'រុស្ស៊ី (បេឡារុស)',
        'ru_KG' => 'រុស្ស៊ី (កៀហ្ស៊ីស៊ីស្ថាន)',
        'ru_KZ' => 'រុស្ស៊ី (កាហ្សាក់ស្ថាន)',
        'ru_MD' => 'រុស្ស៊ី (ម៉ុលដាវី)',
        'ru_RU' => 'រុស្ស៊ី (រុស្ស៊ី)',
        'ru_UA' => 'រុស្ស៊ី (អ៊ុយក្រែន)',
        'rw' => 'គិនយ៉ាវ៉ាន់ដា',
        'rw_RW' => 'គិនយ៉ាវ៉ាន់ដា (រវ៉ាន់ដា)',
        'sa' => 'សំស្ក្រឹត',
        'sa_IN' => 'សំស្ក្រឹត (ឥណ្ឌា)',
        'sc' => 'សាឌីនា',
        'sc_IT' => 'សាឌីនា (អ៊ីតាលី)',
        'sd' => 'ស៊ីនឌី',
        'sd_Arab' => 'ស៊ីនឌី (អារ៉ាប់)',
        'sd_Arab_PK' => 'ស៊ីនឌី (អារ៉ាប់, ប៉ាគីស្ថាន)',
        'sd_Deva' => 'ស៊ីនឌី (ដាវ៉ាន់ណាការិ)',
        'sd_Deva_IN' => 'ស៊ីនឌី (ដាវ៉ាន់ណាការិ, ឥណ្ឌា)',
        'sd_IN' => 'ស៊ីនឌី (ឥណ្ឌា)',
        'sd_PK' => 'ស៊ីនឌី (ប៉ាគីស្ថាន)',
        'se' => 'សាមីខាងជើង',
        'se_FI' => 'សាមីខាងជើង (ហ្វាំងឡង់)',
        'se_NO' => 'សាមីខាងជើង (ន័រវែស)',
        'se_SE' => 'សាមីខាងជើង (ស៊ុយអែត)',
        'sg' => 'សានហ្គោ',
        'sg_CF' => 'សានហ្គោ (សាធារណរដ្ឋអាហ្វ្រិកកណ្ដាល)',
        'sh' => 'សឺបូក្រូអាត',
        'sh_BA' => 'សឺបូក្រូអាត (បូស្ន៊ី និងហឺហ្ស៊ីហ្គូវីណា)',
        'si' => 'ស្រីលង្កា',
        'si_LK' => 'ស្រីលង្កា (ស្រីលង្កា)',
        'sk' => 'ស្លូវ៉ាគី',
        'sk_SK' => 'ស្លូវ៉ាគី (ស្លូវ៉ាគី)',
        'sl' => 'ស្លូវ៉ានី',
        'sl_SI' => 'ស្លូវ៉ានី (ស្លូវេនី)',
        'sn' => 'សូណា',
        'sn_ZW' => 'សូណា (ស៊ីមបាវ៉េ)',
        'so' => 'សូម៉ាលី',
        'so_DJ' => 'សូម៉ាលី (ជីប៊ូទី)',
        'so_ET' => 'សូម៉ាលី (អេត្យូពី)',
        'so_KE' => 'សូម៉ាលី (កេនយ៉ា)',
        'so_SO' => 'សូម៉ាលី (សូម៉ាលី)',
        'sq' => 'អាល់បានី',
        'sq_AL' => 'អាល់បានី (អាល់បានី)',
        'sq_MK' => 'អាល់បានី (ម៉ាសេដ្វានខាងជើង)',
        'sr' => 'ស៊ែប',
        'sr_BA' => 'ស៊ែប (បូស្ន៊ី និងហឺហ្ស៊ីហ្គូវីណា)',
        'sr_Cyrl' => 'ស៊ែប (ស៊ីរីលីក)',
        'sr_Cyrl_BA' => 'ស៊ែប (ស៊ីរីលីក, បូស្ន៊ី និងហឺហ្ស៊ីហ្គូវីណា)',
        'sr_Cyrl_ME' => 'ស៊ែប (ស៊ីរីលីក, ម៉ុងតេណេហ្គ្រោ)',
        'sr_Cyrl_RS' => 'ស៊ែប (ស៊ីរីលីក, សែប៊ី)',
        'sr_Latn' => 'ស៊ែប (ឡាតាំង)',
        'sr_Latn_BA' => 'ស៊ែប (ឡាតាំង, បូស្ន៊ី និងហឺហ្ស៊ីហ្គូវីណា)',
        'sr_Latn_ME' => 'ស៊ែប (ឡាតាំង, ម៉ុងតេណេហ្គ្រោ)',
        'sr_Latn_RS' => 'ស៊ែប (ឡាតាំង, សែប៊ី)',
        'sr_ME' => 'ស៊ែប (ម៉ុងតេណេហ្គ្រោ)',
        'sr_RS' => 'ស៊ែប (សែប៊ី)',
        'su' => 'ស៊ូដង់',
        'su_ID' => 'ស៊ូដង់ (ឥណ្ឌូណេស៊ី)',
        'su_Latn' => 'ស៊ូដង់ (ឡាតាំង)',
        'su_Latn_ID' => 'ស៊ូដង់ (ឡាតាំង, ឥណ្ឌូណេស៊ី)',
        'sv' => 'ស៊ុយអែត',
        'sv_AX' => 'ស៊ុយអែត (កោះ​អាឡង់)',
        'sv_FI' => 'ស៊ុយអែត (ហ្វាំងឡង់)',
        'sv_SE' => 'ស៊ុយអែត (ស៊ុយអែត)',
        'sw' => 'ស្វាហ៊ីលី',
        'sw_CD' => 'ស្វាហ៊ីលី (កុងហ្គោ- គីនស្ហាសា)',
        'sw_KE' => 'ស្វាហ៊ីលី (កេនយ៉ា)',
        'sw_TZ' => 'ស្វាហ៊ីលី (តង់សានី)',
        'sw_UG' => 'ស្វាហ៊ីលី (អ៊ូហ្គង់ដា)',
        'ta' => 'តាមីល',
        'ta_IN' => 'តាមីល (ឥណ្ឌា)',
        'ta_LK' => 'តាមីល (ស្រីលង្កា)',
        'ta_MY' => 'តាមីល (ម៉ាឡេស៊ី)',
        'ta_SG' => 'តាមីល (សិង្ហបុរី)',
        'te' => 'តេលុគុ',
        'te_IN' => 'តេលុគុ (ឥណ្ឌា)',
        'tg' => 'តាហ្ស៊ីគ',
        'tg_TJ' => 'តាហ្ស៊ីគ (តាហ្ស៊ីគីស្ថាន)',
        'th' => 'ថៃ',
        'th_TH' => 'ថៃ (ថៃ)',
        'ti' => 'ទីហ្គ្រីញ៉ា',
        'ti_ER' => 'ទីហ្គ្រីញ៉ា (អេរីត្រេ)',
        'ti_ET' => 'ទីហ្គ្រីញ៉ា (អេត្យូពី)',
        'tk' => 'តួកម៉េន',
        'tk_TM' => 'តួកម៉េន (តួកម៉េនីស្ថាន)',
        'to' => 'តុងហ្គា',
        'to_TO' => 'តុងហ្គា (តុងហ្គា)',
        'tr' => 'ទួរគី',
        'tr_CY' => 'ទួរគី (ស៊ីប)',
        'tr_TR' => 'ទួរគី (តួកគី)',
        'tt' => 'តាតា',
        'tt_RU' => 'តាតា (រុស្ស៊ី)',
        'ug' => 'អ៊ុយហ្គឺរ',
        'ug_CN' => 'អ៊ុយហ្គឺរ (ចិន)',
        'uk' => 'អ៊ុយក្រែន',
        'uk_UA' => 'អ៊ុយក្រែន (អ៊ុយក្រែន)',
        'ur' => 'អ៊ូរឌូ',
        'ur_IN' => 'អ៊ូរឌូ (ឥណ្ឌា)',
        'ur_PK' => 'អ៊ូរឌូ (ប៉ាគីស្ថាន)',
        'uz' => 'អ៊ូសបេគ',
        'uz_AF' => 'អ៊ូសបេគ (អាហ្វហ្កានីស្ថាន)',
        'uz_Arab' => 'អ៊ូសបេគ (អារ៉ាប់)',
        'uz_Arab_AF' => 'អ៊ូសបេគ (អារ៉ាប់, អាហ្វហ្កានីស្ថាន)',
        'uz_Cyrl' => 'អ៊ូសបេគ (ស៊ីរីលីក)',
        'uz_Cyrl_UZ' => 'អ៊ូសបេគ (ស៊ីរីលីក, អ៊ូសបេគីស្ថាន)',
        'uz_Latn' => 'អ៊ូសបេគ (ឡាតាំង)',
        'uz_Latn_UZ' => 'អ៊ូសបេគ (ឡាតាំង, អ៊ូសបេគីស្ថាន)',
        'uz_UZ' => 'អ៊ូសបេគ (អ៊ូសបេគីស្ថាន)',
        'vi' => 'វៀតណាម',
        'vi_VN' => 'វៀតណាម (វៀតណាម)',
        'wo' => 'វូឡុហ្វ',
        'wo_SN' => 'វូឡុហ្វ (សេណេហ្គាល់)',
        'xh' => 'ឃសា',
        'xh_ZA' => 'ឃសា (អាហ្វ្រិកខាងត្បូង)',
        'yi' => 'យ៉ីឌីស',
        'yi_001' => 'យ៉ីឌីស (ពិភពលោក)',
        'yo' => 'យរូបា',
        'yo_BJ' => 'យរូបា (បេណាំង)',
        'yo_NG' => 'យរូបា (នីហ្សេរីយ៉ា)',
        'zh' => 'ចិន',
        'zh_CN' => 'ចិន (ចិន)',
        'zh_HK' => 'ចិន (ហុងកុង តំបន់រដ្ឋបាលពិសេសចិន)',
        'zh_Hans' => 'ចិន (អក្សរ​ចិន​កាត់)',
        'zh_Hans_CN' => 'ចិន (អក្សរ​ចិន​កាត់, ចិន)',
        'zh_Hans_HK' => 'ចិន (អក្សរ​ចិន​កាត់, ហុងកុង តំបន់រដ្ឋបាលពិសេសចិន)',
        'zh_Hans_MO' => 'ចិន (អក្សរ​ចិន​កាត់, ម៉ាកាវ តំបន់រដ្ឋបាលពិសេសចិន)',
        'zh_Hans_SG' => 'ចិន (អក្សរ​ចិន​កាត់, សិង្ហបុរី)',
        'zh_Hant' => 'ចិន (អក្សរ​ចិន​ពេញ)',
        'zh_Hant_HK' => 'ចិន (អក្សរ​ចិន​ពេញ, ហុងកុង តំបន់រដ្ឋបាលពិសេសចិន)',
        'zh_Hant_MO' => 'ចិន (អក្សរ​ចិន​ពេញ, ម៉ាកាវ តំបន់រដ្ឋបាលពិសេសចិន)',
        'zh_Hant_TW' => 'ចិន (អក្សរ​ចិន​ពេញ, តៃវ៉ាន់)',
        'zh_MO' => 'ចិន (ម៉ាកាវ តំបន់រដ្ឋបាលពិសេសចិន)',
        'zh_SG' => 'ចិន (សិង្ហបុរី)',
        'zh_TW' => 'ចិន (តៃវ៉ាន់)',
        'zu' => 'ហ្សូលូ',
        'zu_ZA' => 'ហ្សូលូ (អាហ្វ្រិកខាងត្បូង)',
    ],
];
